==> zio-aws-apigatewayv2_3-5.17.127.2-sources.jar: zio/aws/apigatewayv2/model/GetApiMappingRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetApiMappingRequest(
    apiMappingId: __string,
    domainName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest = {
    import GetApiMappingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
      .builder()
      .apiMappingId(__string.unwrap(apiMappingId): java.lang.String)
      .domainName(__string.unwrap(domainName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetApiMappingRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetApiMappingRequest.wrap(buildAwsValue())
}
object GetApiMappingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetApiMappingRequest =
      zio.aws.apigatewayv2.model.GetApiMappingRequest(apiMappingId, domainName)
    def apiMappingId: __string
    def domainName: __string
    def getApiMappingId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiMappingId)
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
  ) extends zio.aws.apigatewayv2.model.GetApiMappingRequest.ReadOnly {
    override val apiMappingId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiMappingId())
    override val domainName: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.domainName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
  ): zio.aws.apigatewayv2.model.GetApiMappingRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-apigatewayv2_3-5.17.158.2-sources.jar: zio/aws/apigatewayv2/model/GetApiMappingRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetApiMappingRequest(
    apiMappingId: __string,
    domainName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest = {
    import GetApiMappingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
      .builder()
      .apiMappingId(apiMappingId: java.lang.String)
      .domainName(domainName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.GetApiMappingRequest.ReadOnly =
    zio.aws.apigatewayv2.model.GetApiMappingRequest.wrap(buildAwsValue())
}
object GetApiMappingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.GetApiMappingRequest =
      zio.aws.apigatewayv2.model.GetApiMappingRequest(apiMappingId, domainName)
    def apiMappingId: __string
    def domainName: __string
    def getApiMappingId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiMappingId)
    def getDomainName: ZIO[Any, Nothing, __string] = ZIO.succeed(domainName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
  ) extends zio.aws.apigatewayv2.model.GetApiMappingRequest.ReadOnly {
    override val apiMappingId: __string = impl.apiMappingId(): __string
    override val domainName: __string = impl.domainName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.GetApiMappingRequest
  ): zio.aws.apigatewayv2.model.GetApiMappingRequest.ReadOnly = new Wrapper(
    impl
  )
}
